const os = require("os");
let addon;
try {
  if (!process.versions || !process.versions.napi) {
    throw new Error("no n-api support");
  }
  if (os.platform() === "darwin") {
    addon = require("./mac_build/Release/int64Convert.node");
  } else if (os.platform() === "linux") {
    addon = require("./linux_build/Release/int64Convert.node");
  }
} catch (error) {
  // console.log(error);
  addon = require("int64-convert");
}
// console.log('addon:',addon);
// console.log(addon.signedHexToDec('8fffffffffffffff'));
// console.log(addon.signedDecToHex('9223372036854775807'));

/*
 * @desc polish number string, add front zero
 * @params {String} number string
 * @params {Number} target length
 * @return {String} polished number string
 */
function polish(str, len) {
  while (str.length < len) {
    str = "0" + str;
  }
  return str;
}
/*
 * @desc convert char to number
 * @params {String} number char
 * @params {Number} scale
 * @return {Number} polished number string
 */
function toNumber(char, scale) {
  if (!char) {
    return 0;
  }
  var num = parseInt(char, scale);
  if (isNaN(num)) {
    throw new Error(
      "parse char '" + char + "' to number(" + scale + ") failed"
    );
  }
  return num;
}
const jsWrapper = {
  signedHexToDec: function(hexString, polishNumber) {
    let result = addon.signedHexToDec(hexString);
    if (polishNumber) {
      result = polish(result, polishNumber);
    }
    return result;
  },
  signedDecToHex: function(hexString, polishNumber) {
    for (let i = hexString.length - 1; i > 0; i--) {
      toNumber(hexString[i], 10);
    }
    let result = addon.signedDecToHex(hexString);
    if (polishNumber) {
      result = polish(result, polishNumber);
    }
    return result;
  }
};

module.exports = jsWrapper;
